
## Introduction

`flowws-freud` is an in-development set of modules to create reusable
pipelines for scientific simulations using
[freud](https://freud.readthedocs.io).

`flowws-freud` is being developed in conjunction with
[flowws](https://github.com/klarh/flowws).

## Installation

Install `flowws-freud` from PyPI:

```
pip install flowws-freud
```

Alternatively, install from source:

```
pip install git+https://github.com/klarh/flowws-freud.git#egg=flowws-freud
```

## Documentation

Browse more detailed documentation
[online](https://flowws-freud.readthedocs.io) or build the sphinx
documentation from source:

```
git clone https://github.com/klarh/flowws-freud
cd flowws-freud/doc
pip install -r requirements.txt
make html
```
